@@ -1,7 +1,10 @@
 import default_args 
 
+ec = default_args.EnumClass()
+if not ec.blah():
+  raise RuntimeError,"EnumClass::blah() default arguments don't work"
 
-if default_args.Statics.staticMethod() != 60:
+if default_args.Statics_staticMethod() != 60:
   raise RuntimeError
   
 if default_args.cfunc1(1) != 2:
