@@ -66,12 +66,15 @@ except MyException, e:
 if not ok:
 	raise RuntimeError
 
-try:
-	raise Exception2()
-except Exception2:
-	pass
+# This is expected to fail with -builtin option
+# Throwing builtin classes as exceptions not supported
+if not is_python_builtin():
+	try:
+		raise Exception2()
+	except Exception2:
+		pass
 
-try:
-	raise Exception1()
-except Exception1:
-	pass
+	try:
+		raise Exception1()
+	except Exception1:
+		pass
