@@ -1,19 +1,19 @@
-/* A Bison parser, made by GNU Bison 2.5.  */
+/* A Bison parser, made by GNU Bison 3.0.2.  */
 
 /* Bison interface for Yacc-like parsers in C
-   
-      Copyright (C) 1984, 1989-1990, 2000-2011 Free Software Foundation, Inc.
-   
+
+   Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
+
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
-   
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
@@ -26,156 +26,164 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-   
+
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
+#ifndef YY_YY_Y_TAB_H_INCLUDED
+# define YY_YY_Y_TAB_H_INCLUDED
+/* Debug traces.  */
+#ifndef YYDEBUG
+# define YYDEBUG 0
+#endif
+#if YYDEBUG
+extern int yydebug;
+#endif
 
-/* Tokens.  */
+/* Token type.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
-   /* Put the tokens into the symbol table, so that GDB and other debuggers
-      know about them.  */
-   enum yytokentype {
-     ID = 258,
-     HBLOCK = 259,
-     POUND = 260,
-     STRING = 261,
-     WSTRING = 262,
-     INCLUDE = 263,
-     IMPORT = 264,
-     INSERT = 265,
-     CHARCONST = 266,
-     WCHARCONST = 267,
-     NUM_INT = 268,
-     NUM_FLOAT = 269,
-     NUM_UNSIGNED = 270,
-     NUM_LONG = 271,
-     NUM_ULONG = 272,
-     NUM_LONGLONG = 273,
-     NUM_ULONGLONG = 274,
-     NUM_BOOL = 275,
-     TYPEDEF = 276,
-     TYPE_INT = 277,
-     TYPE_UNSIGNED = 278,
-     TYPE_SHORT = 279,
-     TYPE_LONG = 280,
-     TYPE_FLOAT = 281,
-     TYPE_DOUBLE = 282,
-     TYPE_CHAR = 283,
-     TYPE_WCHAR = 284,
-     TYPE_VOID = 285,
-     TYPE_SIGNED = 286,
-     TYPE_BOOL = 287,
-     TYPE_COMPLEX = 288,
-     TYPE_TYPEDEF = 289,
-     TYPE_RAW = 290,
-     TYPE_NON_ISO_INT8 = 291,
-     TYPE_NON_ISO_INT16 = 292,
-     TYPE_NON_ISO_INT32 = 293,
-     TYPE_NON_ISO_INT64 = 294,
-     LPAREN = 295,
-     RPAREN = 296,
-     COMMA = 297,
-     SEMI = 298,
-     EXTERN = 299,
-     INIT = 300,
-     LBRACE = 301,
-     RBRACE = 302,
-     PERIOD = 303,
-     CONST_QUAL = 304,
-     VOLATILE = 305,
-     REGISTER = 306,
-     STRUCT = 307,
-     UNION = 308,
-     EQUAL = 309,
-     SIZEOF = 310,
-     MODULE = 311,
-     LBRACKET = 312,
-     RBRACKET = 313,
-     BEGINFILE = 314,
-     ENDOFFILE = 315,
-     ILLEGAL = 316,
-     CONSTANT = 317,
-     NAME = 318,
-     RENAME = 319,
-     NAMEWARN = 320,
-     EXTEND = 321,
-     PRAGMA = 322,
-     FEATURE = 323,
-     VARARGS = 324,
-     ENUM = 325,
-     CLASS = 326,
-     TYPENAME = 327,
-     PRIVATE = 328,
-     PUBLIC = 329,
-     PROTECTED = 330,
-     COLON = 331,
-     STATIC = 332,
-     VIRTUAL = 333,
-     FRIEND = 334,
-     THROW = 335,
-     CATCH = 336,
-     EXPLICIT = 337,
-     STATIC_ASSERT = 338,
-     CONSTEXPR = 339,
-     THREAD_LOCAL = 340,
-     DECLTYPE = 341,
-     AUTO = 342,
-     NOEXCEPT = 343,
-     OVERRIDE = 344,
-     FINAL = 345,
-     USING = 346,
-     NAMESPACE = 347,
-     NATIVE = 348,
-     INLINE = 349,
-     TYPEMAP = 350,
-     EXCEPT = 351,
-     ECHO = 352,
-     APPLY = 353,
-     CLEAR = 354,
-     SWIGTEMPLATE = 355,
-     FRAGMENT = 356,
-     WARN = 357,
-     LESSTHAN = 358,
-     GREATERTHAN = 359,
-     DELETE_KW = 360,
-     DEFAULT = 361,
-     LESSTHANOREQUALTO = 362,
-     GREATERTHANOREQUALTO = 363,
-     EQUALTO = 364,
-     NOTEQUALTO = 365,
-     ARROW = 366,
-     QUESTIONMARK = 367,
-     TYPES = 368,
-     PARMS = 369,
-     NONID = 370,
-     DSTAR = 371,
-     DCNOT = 372,
-     TEMPLATE = 373,
-     OPERATOR = 374,
-     COPERATOR = 375,
-     PARSETYPE = 376,
-     PARSEPARM = 377,
-     PARSEPARMS = 378,
-     CAST = 379,
-     LOR = 380,
-     LAND = 381,
-     OR = 382,
-     XOR = 383,
-     AND = 384,
-     RSHIFT = 385,
-     LSHIFT = 386,
-     MINUS = 387,
-     PLUS = 388,
-     MODULO = 389,
-     SLASH = 390,
-     STAR = 391,
-     LNOT = 392,
-     NOT = 393,
-     UMINUS = 394,
-     DCOLON = 395
-   };
+  enum yytokentype
+  {
+    ID = 258,
+    HBLOCK = 259,
+    POUND = 260,
+    STRING = 261,
+    WSTRING = 262,
+    INCLUDE = 263,
+    IMPORT = 264,
+    INSERT = 265,
+    CHARCONST = 266,
+    WCHARCONST = 267,
+    NUM_INT = 268,
+    NUM_FLOAT = 269,
+    NUM_UNSIGNED = 270,
+    NUM_LONG = 271,
+    NUM_ULONG = 272,
+    NUM_LONGLONG = 273,
+    NUM_ULONGLONG = 274,
+    NUM_BOOL = 275,
+    TYPEDEF = 276,
+    TYPE_INT = 277,
+    TYPE_UNSIGNED = 278,
+    TYPE_SHORT = 279,
+    TYPE_LONG = 280,
+    TYPE_FLOAT = 281,
+    TYPE_DOUBLE = 282,
+    TYPE_CHAR = 283,
+    TYPE_WCHAR = 284,
+    TYPE_VOID = 285,
+    TYPE_SIGNED = 286,
+    TYPE_BOOL = 287,
+    TYPE_COMPLEX = 288,
+    TYPE_TYPEDEF = 289,
+    TYPE_RAW = 290,
+    TYPE_NON_ISO_INT8 = 291,
+    TYPE_NON_ISO_INT16 = 292,
+    TYPE_NON_ISO_INT32 = 293,
+    TYPE_NON_ISO_INT64 = 294,
+    LPAREN = 295,
+    RPAREN = 296,
+    COMMA = 297,
+    SEMI = 298,
+    EXTERN = 299,
+    INIT = 300,
+    LBRACE = 301,
+    RBRACE = 302,
+    PERIOD = 303,
+    CONST_QUAL = 304,
+    VOLATILE = 305,
+    REGISTER = 306,
+    STRUCT = 307,
+    UNION = 308,
+    EQUAL = 309,
+    SIZEOF = 310,
+    MODULE = 311,
+    LBRACKET = 312,
+    RBRACKET = 313,
+    BEGINFILE = 314,
+    ENDOFFILE = 315,
+    ILLEGAL = 316,
+    CONSTANT = 317,
+    NAME = 318,
+    RENAME = 319,
+    NAMEWARN = 320,
+    EXTEND = 321,
+    PRAGMA = 322,
+    FEATURE = 323,
+    VARARGS = 324,
+    ENUM = 325,
+    CLASS = 326,
+    TYPENAME = 327,
+    PRIVATE = 328,
+    PUBLIC = 329,
+    PROTECTED = 330,
+    COLON = 331,
+    STATIC = 332,
+    VIRTUAL = 333,
+    FRIEND = 334,
+    THROW = 335,
+    CATCH = 336,
+    EXPLICIT = 337,
+    STATIC_ASSERT = 338,
+    CONSTEXPR = 339,
+    THREAD_LOCAL = 340,
+    DECLTYPE = 341,
+    AUTO = 342,
+    NOEXCEPT = 343,
+    OVERRIDE = 344,
+    FINAL = 345,
+    USING = 346,
+    NAMESPACE = 347,
+    NATIVE = 348,
+    INLINE = 349,
+    TYPEMAP = 350,
+    EXCEPT = 351,
+    ECHO = 352,
+    APPLY = 353,
+    CLEAR = 354,
+    SWIGTEMPLATE = 355,
+    FRAGMENT = 356,
+    WARN = 357,
+    LESSTHAN = 358,
+    GREATERTHAN = 359,
+    DELETE_KW = 360,
+    DEFAULT = 361,
+    LESSTHANOREQUALTO = 362,
+    GREATERTHANOREQUALTO = 363,
+    EQUALTO = 364,
+    NOTEQUALTO = 365,
+    ARROW = 366,
+    QUESTIONMARK = 367,
+    TYPES = 368,
+    PARMS = 369,
+    NONID = 370,
+    DSTAR = 371,
+    DCNOT = 372,
+    TEMPLATE = 373,
+    OPERATOR = 374,
+    COPERATOR = 375,
+    PARSETYPE = 376,
+    PARSEPARM = 377,
+    PARSEPARMS = 378,
+    CAST = 379,
+    LOR = 380,
+    LAND = 381,
+    OR = 382,
+    XOR = 383,
+    AND = 384,
+    LSHIFT = 385,
+    RSHIFT = 386,
+    PLUS = 387,
+    MINUS = 388,
+    STAR = 389,
+    SLASH = 390,
+    MODULO = 391,
+    UMINUS = 392,
+    NOT = 393,
+    LNOT = 394,
+    DCOLON = 395
+  };
 #endif
 /* Tokens.  */
 #define ID 258
@@ -305,27 +313,24 @@
 #define OR 382
 #define XOR 383
 #define AND 384
-#define RSHIFT 385
-#define LSHIFT 386
-#define MINUS 387
-#define PLUS 388
-#define MODULO 389
+#define LSHIFT 385
+#define RSHIFT 386
+#define PLUS 387
+#define MINUS 388
+#define STAR 389
 #define SLASH 390
-#define STAR 391
-#define LNOT 392
+#define MODULO 391
+#define UMINUS 392
 #define NOT 393
-#define UMINUS 394
+#define LNOT 394
 #define DCOLON 395
 
-
-
-
+/* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-typedef union YYSTYPE
+typedef union YYSTYPE YYSTYPE;
+union YYSTYPE
 {
-
-/* Line 2068 of yacc.c  */
-#line 1298 "parser.y"
+#line 1299 "parser.y" /* yacc.c:1909  */
 
   char  *id;
   List  *bases;
@@ -370,16 +375,15 @@ typedef union YYSTYPE
   int           intvalue;
   Node         *node;
 
-
-
-/* Line 2068 of yacc.c  */
-#line 377 "y.tab.h"
-} YYSTYPE;
+#line 379 "y.tab.h" /* yacc.c:1909  */
+};
 # define YYSTYPE_IS_TRIVIAL 1
-# define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 #endif
 
+
 extern YYSTYPE yylval;
 
+int yyparse (void);
 
+#endif /* !YY_YY_Y_TAB_H_INCLUDED  */
