@@ -17,8 +17,6 @@
  * - Lines beginning with %# are stripped down to #... and passed through.
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_cpp_c[] = "$Id: cpp.c 13939 2012-11-26 20:30:37Z wsfulton $";
-
 #include "swig.h"
 #include "preprocessor.h"
 #include <ctype.h>
@@ -1770,6 +1768,10 @@ String *Preprocessor_parse(String *s) {
 	}
       } else if (Equal(id, kpp_level)) {
 	Swig_error(Getfile(s), Getline(id), "cpp debug: level = %d, startlevel = %d\n", level, start_level);
+      } else if (Equal(id, "")) {
+	/* Null directive */
+      } else {
+	Swig_error(Getfile(s), Getline(id), "Unknown SWIG preprocessor directive: %s\n", id);
       }
       for (i = 0; i < cpp_lines; i++)
 	Putc('\n', ns);
